#
# spec file for package python-cssselect2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-cssselect2
Version:        0.7.0
Release:        2.3
Summary:        CSS selectors for Python ElementTree
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/Kozea/cssselect2/
Source:         https://github.com/Kozea/cssselect2/archive/refs/tags/%{version}.tar.gz#/cssselect2-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-tinycss2
Requires:       python-webencodings
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tinycss2}
BuildRequires:  %{python_module webencodings}
# /SECTION
%python_subpackages

%description
CSSselect2 is an implementation of CSS3 Selectors for markup
documents (HTML, XML, etc.) that can be read by ElementTree-like
parsers (including cElementTree, lxml, html5lib, etc.)

Unlike cssselect, it does not translate selectors to XPath and therefore does
not have all the correctness corner cases that are hard or impossible to fix in
cssselect.

%prep
%setup -q -n cssselect2-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest -v

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/cssselect2
%{python_sitelib}/cssselect2-%{version}*-info

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Mar 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.7.0:
  * Support :has selector
  0.6.0:
  * Improve speed of ancestors and previous siblings
  0.5.0:
  * Support Python 3.10
  * Drop support of Python 3.6
  * Handle many CSS4 selectors
  * Ignore comments at the beginning of selectors
  0.4.1:
  * Fix PyPI description and various links.
  0.4.0:
  * Drop support of Python 3.5, add support of Python 3.9.
  * Don’t crash on empty :not() selectors.
  * New code structure, new packaging, new documentation.
* Wed Apr  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.3.0
  * Drop Python2 support
  * Improve packaging and testing
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.2:
  * Optimize lang attribute selectors
* Fri Apr 26 2019 pgajdos@suse.com
- python3 package only as python-tinycss2 become too
* Wed Feb 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix the build again
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary build dependencies on pytest plugins, by
  invoking pytest directly avoiding setup.py checking test deps,
  and removing addopts from setup.cfg
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- Initial version
